summaryrefslogtreecommitdiff
path: root/sw
diff options
context:
space:
mode:
authorNoel Grandin <noel.grandin@collabora.co.uk>2020-02-04 11:08:31 +0200
committerNoel Grandin <noel.grandin@collabora.co.uk>2020-02-04 13:10:58 +0100
commit042054d0507bac8ede0c045a58a91c0830312fc5 (patch)
tree92e277a04a9ffc5923f809bf1163c221d32127d1 /sw
parent4d307299bc7aada87d13810f12b9868045d15743 (diff)
rename GetOfst -> GetOffset
Change-Id: I9c0968bd93f41f983468ee7ba8a20e27c4866b32 Reviewed-on: https://gerrit.libreoffice.org/c/core/+/87954 Tested-by: Jenkins Reviewed-by: Noel Grandin <noel.grandin@collabora.co.uk>
Diffstat (limited to 'sw')
-rw-r--r--sw/source/core/access/acccontext.cxx2
-rw-r--r--sw/source/core/access/accpara.cxx6
-rw-r--r--sw/source/core/access/parachangetrackinginfo.cxx4
-rw-r--r--sw/source/core/crsr/callnk.cxx2
-rw-r--r--sw/source/core/crsr/trvlfnfl.cxx2
-rw-r--r--sw/source/core/doc/doc.cxx4
-rw-r--r--sw/source/core/doc/doctxm.cxx2
-rw-r--r--sw/source/core/draw/dcontact.cxx2
-rw-r--r--sw/source/core/inc/drawfont.hxx2
-rw-r--r--sw/source/core/inc/txtfrm.hxx8
-rw-r--r--sw/source/core/layout/anchoredobject.cxx2
-rw-r--r--sw/source/core/layout/fly.cxx4
-rw-r--r--sw/source/core/layout/laycache.cxx4
-rw-r--r--sw/source/core/layout/objectformattertxtfrm.cxx4
-rw-r--r--sw/source/core/layout/softpagebreak.cxx4
-rw-r--r--sw/source/core/layout/trvlfrm.cxx6
-rw-r--r--sw/source/core/text/frmcrsr.cxx34
-rw-r--r--sw/source/core/text/frmform.cxx36
-rw-r--r--sw/source/core/text/frmpaint.cxx6
-rw-r--r--sw/source/core/text/inftxt.cxx2
-rw-r--r--sw/source/core/text/inftxt.hxx2
-rw-r--r--sw/source/core/text/itratr.cxx2
-rw-r--r--sw/source/core/text/itrcrsr.cxx2
-rw-r--r--sw/source/core/text/itrform2.cxx6
-rw-r--r--sw/source/core/text/itrtxt.cxx2
-rw-r--r--sw/source/core/text/porlay.hxx2
-rw-r--r--sw/source/core/text/txtfrm.cxx46
-rw-r--r--sw/source/core/text/txtftn.cxx20
-rw-r--r--sw/source/core/text/widorp.cxx2
-rw-r--r--sw/source/core/txtnode/fntcache.cxx12
-rw-r--r--sw/source/core/txtnode/fntcap.cxx2
-rw-r--r--sw/source/core/txtnode/ndtxt.cxx2
-rw-r--r--sw/source/core/txtnode/txtedt.cxx8
33 files changed, 122 insertions, 122 deletions
diff --git a/sw/source/core/access/acccontext.cxx b/sw/source/core/access/acccontext.cxx
index 0e8d45f91a24..3b9f0f1e61cc 100644
--- a/sw/source/core/access/acccontext.cxx
+++ b/sw/source/core/access/acccontext.cxx
@@ -990,7 +990,7 @@ void SAL_CALL SwAccessibleContext::grabFocus()
if( pTextNd )
{
// create pam for selection
- SwPosition const aStartPos(pTextFrame->MapViewToModelPos(pTextFrame->GetOfst()));
+ SwPosition const aStartPos(pTextFrame->MapViewToModelPos(pTextFrame->GetOffset()));
SwPaM aPaM( aStartPos );
// set PaM at cursor shell
diff --git a/sw/source/core/access/accpara.cxx b/sw/source/core/access/accpara.cxx
index 8b4a1658d5e4..65fa30f36d9e 100644
--- a/sw/source/core/access/accpara.cxx
+++ b/sw/source/core/access/accpara.cxx
@@ -784,7 +784,7 @@ void SAL_CALL SwAccessibleParagraph::grabFocus()
!pTextFrame->IsInside(pTextFrame->MapModelToViewPos(*pCursor->GetPoint()))))
{
// create pam for selection
- SwPosition const aStartPos(pTextFrame->MapViewToModelPos(pTextFrame->GetOfst()));
+ SwPosition const aStartPos(pTextFrame->MapViewToModelPos(pTextFrame->GetOffset()));
SwPaM aPaM( aStartPos );
// set PaM at cursor shell
@@ -2720,10 +2720,10 @@ public:
SwHyperlinkIter_Impl::SwHyperlinkIter_Impl(const SwTextFrame & rTextFrame)
: m_rFrame(rTextFrame)
, m_Iter(rTextFrame)
- , m_nStt(rTextFrame.GetOfst())
+ , m_nStt(rTextFrame.GetOffset())
{
const SwTextFrame *const pFollFrame = rTextFrame.GetFollow();
- m_nEnd = pFollFrame ? pFollFrame->GetOfst() : TextFrameIndex(rTextFrame.GetText().getLength());
+ m_nEnd = pFollFrame ? pFollFrame->GetOffset() : TextFrameIndex(rTextFrame.GetText().getLength());
}
const SwTextAttr *SwHyperlinkIter_Impl::next(SwTextNode const** ppNode)
diff --git a/sw/source/core/access/parachangetrackinginfo.cxx b/sw/source/core/access/parachangetrackinginfo.cxx
index 8ddeee61a344..5fcc6f41c8db 100644
--- a/sw/source/core/access/parachangetrackinginfo.cxx
+++ b/sw/source/core/access/parachangetrackinginfo.cxx
@@ -71,10 +71,10 @@ namespace {
// sw_redlinehide: rely on the Hide early return above & cast
// TextFrameIndex to SwIndex directly
const sal_Int32 nTextFrameTextStartPos = rTextFrame.IsFollow()
- ? sal_Int32(rTextFrame.GetOfst())
+ ? sal_Int32(rTextFrame.GetOffset())
: 0;
const sal_Int32 nTextFrameTextEndPos = rTextFrame.HasFollow()
- ? sal_Int32(rTextFrame.GetFollow()->GetOfst())
+ ? sal_Int32(rTextFrame.GetFollow()->GetOffset())
: rTextFrame.GetText().getLength();
// iteration over the redlines which overlap with the text node.
diff --git a/sw/source/core/crsr/callnk.cxx b/sw/source/core/crsr/callnk.cxx
index 2d5bbab2a20c..4d27742fca12 100644
--- a/sw/source/core/crsr/callnk.cxx
+++ b/sw/source/core/crsr/callnk.cxx
@@ -225,7 +225,7 @@ long SwCallLink::getLayoutFrame(const SwRootFrame* pRoot,
{
TextFrameIndex const nPos(pFrame->MapModelToView(&rNd, nCntPos));
while( nullptr != ( pNext = pFrame->GetFollow() ) &&
- nPos >= pNext->GetOfst())
+ nPos >= pNext->GetOffset())
pFrame = pNext;
}
diff --git a/sw/source/core/crsr/trvlfnfl.cxx b/sw/source/core/crsr/trvlfnfl.cxx
index 00aa045f7f5d..86ef09fbdd04 100644
--- a/sw/source/core/crsr/trvlfnfl.cxx
+++ b/sw/source/core/crsr/trvlfnfl.cxx
@@ -109,7 +109,7 @@ bool SwCursorShell::GotoFootnoteText()
SwTextFrame const*const pTF(
static_cast<const SwTextFrame*>(pCnt));
*GetCursor_()->GetPoint() =
- pTF->MapViewToModelPos(pTF->GetOfst());
+ pTF->MapViewToModelPos(pTF->GetOffset());
UpdateCursor( SwCursorShell::SCROLLWIN |
SwCursorShell::CHKRANGE | SwCursorShell::READONLY );
bRet = true;
diff --git a/sw/source/core/doc/doc.cxx b/sw/source/core/doc/doc.cxx
index 7cf8984bbae9..ad27eafd802f 100644
--- a/sw/source/core/doc/doc.cxx
+++ b/sw/source/core/doc/doc.cxx
@@ -496,8 +496,8 @@ sal_uInt16 PostItField_::GetPageNo(
{
TextFrameIndex const nPos = pFrame->MapModelToView(
&GetTextField()->GetTextNode(), GetContent());
- if( pFrame->GetOfst() > nPos ||
- (pFrame->HasFollow() && pFrame->GetFollow()->GetOfst() <= nPos) )
+ if( pFrame->GetOffset() > nPos ||
+ (pFrame->HasFollow() && pFrame->GetFollow()->GetOffset() <= nPos) )
continue;
sal_uInt16 nPgNo = pFrame->GetPhyPageNum();
if( rRangeEnum.hasValue( nPgNo, &rPossiblePages ))
diff --git a/sw/source/core/doc/doctxm.cxx b/sw/source/core/doc/doctxm.cxx
index d85c58d67689..27e5c60c73b8 100644
--- a/sw/source/core/doc/doctxm.cxx
+++ b/sw/source/core/doc/doctxm.cxx
@@ -1658,7 +1658,7 @@ void SwTOXBaseSection::UpdatePageNum()
->MapModelToView(static_cast<SwTextNode const*>(rTOXSource.pNd),
rTOXSource.nPos));
while( nullptr != ( pNext = static_cast<SwTextFrame*>(pFrame->GetFollow()) )
- && nPos >= pNext->GetOfst())
+ && nPos >= pNext->GetOffset())
pFrame = pNext;
}
diff --git a/sw/source/core/draw/dcontact.cxx b/sw/source/core/draw/dcontact.cxx
index 1b78c24aa0dc..7545f83d4d5c 100644
--- a/sw/source/core/draw/dcontact.cxx
+++ b/sw/source/core/draw/dcontact.cxx
@@ -1707,7 +1707,7 @@ static SwTextFrame* lcl_GetFlyInContentAnchor( SwTextFrame* _pProposedAnchorFram
pTmp = pAct;
pAct = pTmp->GetFollow();
}
- while (pAct && nTextOffset >= pAct->GetOfst());
+ while (pAct && nTextOffset >= pAct->GetOffset());
return pTmp;
}
diff --git a/sw/source/core/inc/drawfont.hxx b/sw/source/core/inc/drawfont.hxx
index 7c35b4a9a67b..2672b82d4b56 100644
--- a/sw/source/core/inc/drawfont.hxx
+++ b/sw/source/core/inc/drawfont.hxx
@@ -270,7 +270,7 @@ public:
return m_nLen;
}
- sal_Int32 GetOfst() const
+ sal_Int32 GetOffset() const
{
#ifdef DBG_UTIL
OSL_ENSURE( m_bOfst, "DrawTextInfo: Undefined Offset" );
diff --git a/sw/source/core/inc/txtfrm.hxx b/sw/source/core/inc/txtfrm.hxx
index 11e975c6b004..944929a5965f 100644
--- a/sw/source/core/inc/txtfrm.hxx
+++ b/sw/source/core/inc/txtfrm.hxx
@@ -425,7 +425,7 @@ public:
/// Methods to manage the FollowFrame
void SplitFrame(TextFrameIndex nTextPos);
SwContentFrame *JoinFrame();
- TextFrameIndex GetOfst() const { return mnOffset; }
+ TextFrameIndex GetOffset() const { return mnOffset; }
void SetOfst_(TextFrameIndex nNewOfst);
inline void SetOfst (TextFrameIndex nNewOfst);
void ManipOfst(TextFrameIndex const nNewOfst) { mnOffset = nNewOfst; }
@@ -434,7 +434,7 @@ public:
SwTextFrame& GetFrameAtOfst(TextFrameIndex nOfst);
/// If there's a Follow and we don't contain text ourselves
bool IsEmptyMaster() const
- { return GetFollow() && !GetFollow()->GetOfst(); }
+ { return GetFollow() && !GetFollow()->GetOffset(); }
void SetMergedPara(std::unique_ptr<sw::MergedPara> p);
sw::MergedPara * GetMergedPara() { return m_pMergedPara.get(); }
@@ -822,12 +822,12 @@ inline SwTwips SwTextFrame::GrowTst( const SwTwips nGrow )
inline bool SwTextFrame::IsInside(TextFrameIndex const nPos) const
{
bool bRet = true;
- if( nPos < GetOfst() )
+ if( nPos < GetOffset() )
bRet = false;
else
{
const SwTextFrame *pFoll = GetFollow();
- if( pFoll && nPos >= pFoll->GetOfst() )
+ if( pFoll && nPos >= pFoll->GetOffset() )
bRet = false;
}
return bRet;
diff --git a/sw/source/core/layout/anchoredobject.cxx b/sw/source/core/layout/anchoredobject.cxx
index 871a6abc0085..f064d20d8035 100644
--- a/sw/source/core/layout/anchoredobject.cxx
+++ b/sw/source/core/layout/anchoredobject.cxx
@@ -545,7 +545,7 @@ bool SwAnchoredObject::HasClearedEnvironment() const
const SwTextFrame* pTmpTextFrame = static_cast<const SwTextFrame*>(pTmpFrame);
if ( pTmpTextFrame->IsUndersized() ||
( pTmpTextFrame->GetFollow() &&
- pTmpTextFrame->GetFollow()->GetOfst() == TextFrameIndex(0)))
+ pTmpTextFrame->GetFollow()->GetOffset() == TextFrameIndex(0)))
{
bHasClearedEnvironment = true;
}
diff --git a/sw/source/core/layout/fly.cxx b/sw/source/core/layout/fly.cxx
index 4ee38db68523..c1054bda87f5 100644
--- a/sw/source/core/layout/fly.cxx
+++ b/sw/source/core/layout/fly.cxx
@@ -1107,7 +1107,7 @@ void SwFlyFrame::ChgRelPos( const Point &rNewPos )
TextFrameIndex const nOfs(pAutoFrame->MapModelToViewPos(
*pFormat->GetAnchor().GetContentAnchor()));
while( pAutoFrame->GetFollow() &&
- pAutoFrame->GetFollow()->GetOfst() <= nOfs )
+ pAutoFrame->GetFollow()->GetOffset() <= nOfs )
{
if( pAutoFrame == GetAnchorFrame() )
nTmpY += pAutoFrame->GetRelPos().Y();
@@ -1163,7 +1163,7 @@ void SwFlyFrame::ChgRelPos( const Point &rNewPos )
TextFrameIndex const nOfs(pAutoFrame->MapModelToViewPos(
*pFormat->GetAnchor().GetContentAnchor()));
while( pAutoFrame->GetFollow() &&
- pAutoFrame->GetFollow()->GetOfst() <= nOfs )
+ pAutoFrame->GetFollow()->GetOffset() <= nOfs )
pAutoFrame = pAutoFrame->GetFollow();
}
nTmpX -= static_cast<SwFlyAtContentFrame*>(this)->GetRelCharX(pAutoFrame);
diff --git a/sw/source/core/layout/laycache.cxx b/sw/source/core/layout/laycache.cxx
index 3fff3bc54cc7..eb824827e4ac 100644
--- a/sw/source/core/layout/laycache.cxx
+++ b/sw/source/core/layout/laycache.cxx
@@ -203,7 +203,7 @@ void SwLayoutCache::Write( SvStream &rStream, const SwDoc& rDoc )
nNdIdx -= nStartOfContent;
aIo.GetStream().WriteUInt32( nNdIdx );
if( bFollow )
- aIo.GetStream().WriteUInt32( sal_Int32(static_cast<SwTextFrame*>(pTmp)->GetOfst()) );
+ aIo.GetStream().WriteUInt32( sal_Int32(static_cast<SwTextFrame*>(pTmp)->GetOffset()) );
aIo.CloseFlagRec();
/* Close Paragraph Record */
aIo.CloseRec();
@@ -360,7 +360,7 @@ bool SwLayoutCache::CompareLayout( const SwDoc& rDoc ) const
SW_LAYCACHE_IO_REC_PARA !=
pImpl->GetBreakType( nIndex ) ||
(bFollow
- ? sal_Int32(static_cast<const SwTextFrame*>(pTmp)->GetOfst())
+ ? sal_Int32(static_cast<const SwTextFrame*>(pTmp)->GetOffset())
: COMPLETE_STRING) != pImpl->GetBreakOfst(nIndex))
{
return false;
diff --git a/sw/source/core/layout/objectformattertxtfrm.cxx b/sw/source/core/layout/objectformattertxtfrm.cxx
index d02cdc2edf07..c8d64cf4449e 100644
--- a/sw/source/core/layout/objectformattertxtfrm.cxx
+++ b/sw/source/core/layout/objectformattertxtfrm.cxx
@@ -276,7 +276,7 @@ bool SwObjectFormatterTextFrame::DoFormatObj( SwAnchoredObject& _rAnchoredObj,
// objects under the condition, that its follow contains all its text.
else if ( !mrAnchorTextFrame.IsFollow() &&
mrAnchorTextFrame.GetFollow() &&
- mrAnchorTextFrame.GetFollow()->GetOfst() == TextFrameIndex(0))
+ mrAnchorTextFrame.GetFollow()->GetOffset() == TextFrameIndex(0))
{
SwLayouter::RemoveMovedFwdFrame(
*(mrAnchorTextFrame.FindPageFrame()->GetFormat()->GetDoc()),
@@ -444,7 +444,7 @@ bool SwObjectFormatterTextFrame::DoFormatObjs()
// objects under the condition, that its follow contains all its text.
else if ( !mrAnchorTextFrame.IsFollow() &&
mrAnchorTextFrame.GetFollow() &&
- mrAnchorTextFrame.GetFollow()->GetOfst() == TextFrameIndex(0))
+ mrAnchorTextFrame.GetFollow()->GetOffset() == TextFrameIndex(0))
{
SwLayouter::RemoveMovedFwdFrame(
*(mrAnchorTextFrame.FindPageFrame()->GetFormat()->GetDoc()),
diff --git a/sw/source/core/layout/softpagebreak.cxx b/sw/source/core/layout/softpagebreak.cxx
index daed905a1826..87ba7c24e653 100644
--- a/sw/source/core/layout/softpagebreak.cxx
+++ b/sw/source/core/layout/softpagebreak.cxx
@@ -80,7 +80,7 @@ void SwTextNode::fillSoftPageBreakList( SwSoftPageBreakList& rBreak ) const
if( pFirst2 == pFrame )
{ // Here we are: a first content inside a cell
// inside the split row => soft page break
- auto const pos(pFrame->MapViewToModel(pFrame->GetOfst()));
+ auto const pos(pFrame->MapViewToModel(pFrame->GetOffset()));
if (pos.first == this)
{
rBreak.insert(pos.second);
@@ -94,7 +94,7 @@ void SwTextNode::fillSoftPageBreakList( SwSoftPageBreakList& rBreak ) const
else // No soft page break if there's a "hard" page break attribute
if( pFirst2 == pFrame && !pFrame->IsPageBreak( true ) )
{
- auto const pos(pFrame->MapViewToModel(pFrame->GetOfst()));
+ auto const pos(pFrame->MapViewToModel(pFrame->GetOffset()));
if (pos.first == this)
{ // in the !Show case, we have to iterate over the merged
// SwTextFrame for every node
diff --git a/sw/source/core/layout/trvlfrm.cxx b/sw/source/core/layout/trvlfrm.cxx
index b0a46504e66a..4000db4d2511 100644
--- a/sw/source/core/layout/trvlfrm.cxx
+++ b/sw/source/core/layout/trvlfrm.cxx
@@ -1032,7 +1032,7 @@ sal_uInt16 SwRootFrame::SetCurrPage( SwCursor* pToSet, sal_uInt16 nPageNum )
{
assert(pContent->IsTextFrame());
SwTextFrame const*const pFrame(static_cast<const SwTextFrame*>(pContent));
- *pToSet->GetPoint() = pFrame->MapViewToModelPos(pFrame->GetOfst());
+ *pToSet->GetPoint() = pFrame->MapViewToModelPos(pFrame->GetOffset());
SwShellCursor* pSCursor = dynamic_cast<SwShellCursor*>(pToSet);
if( pSCursor )
@@ -1129,9 +1129,9 @@ bool GetFrameInPage( const SwContentFrame *pCnt, SwWhichPage fnWhichPage,
assert(pCnt->IsTextFrame());
SwTextFrame const*const pFrame(static_cast<const SwTextFrame*>(pCnt));
TextFrameIndex const nIdx((fnPosPage == GetFirstSub)
- ? pFrame->GetOfst()
+ ? pFrame->GetOffset()
: (pFrame->GetFollow())
- ? pFrame->GetFollow()->GetOfst() - TextFrameIndex(1)
+ ? pFrame->GetFollow()->GetOffset() - TextFrameIndex(1)
: TextFrameIndex(pFrame->GetText().getLength()));
*pPam->GetPoint() = pFrame->MapViewToModelPos(nIdx);
return true;
diff --git a/sw/source/core/text/frmcrsr.cxx b/sw/source/core/text/frmcrsr.cxx
index add8333894a4..ae7ca3d7d0ba 100644
--- a/sw/source/core/text/frmcrsr.cxx
+++ b/sw/source/core/text/frmcrsr.cxx
@@ -70,7 +70,7 @@ SwTextFrame *GetAdjFrameAtPos( SwTextFrame *pFrame, const SwPosition &rPos,
if( !bNoScroll || pFrame->GetFollow() )
{
pFrameAtPos = pFrame->GetFrameAtPos( rPos );
- if (nOffset < pFrameAtPos->GetOfst() &&
+ if (nOffset < pFrameAtPos->GetOffset() &&
!pFrameAtPos->IsFollow() )
{
assert(pFrameAtPos->MapModelToViewPos(rPos) == nOffset);
@@ -92,7 +92,7 @@ SwTextFrame *GetAdjFrameAtPos( SwTextFrame *pFrame, const SwPosition &rPos,
if( nOffset && bRightMargin )
{
while (pFrameAtPos &&
- pFrameAtPos->MapViewToModelPos(pFrameAtPos->GetOfst()) == rPos &&
+ pFrameAtPos->MapViewToModelPos(pFrameAtPos->GetOffset()) == rPos &&
pFrameAtPos->IsFollow() )
{
pFrameAtPos->GetFormatted();
@@ -109,7 +109,7 @@ bool sw_ChangeOffset(SwTextFrame* pFrame, TextFrameIndex nNew)
{
// Do not scroll in areas and outside of flies
OSL_ENSURE( !pFrame->IsFollow(), "Illegal Scrolling by Follow!" );
- if( pFrame->GetOfst() != nNew && !pFrame->IsInSct() )
+ if( pFrame->GetOffset() != nNew && !pFrame->IsInSct() )
{
SwFlyFrame *pFly = pFrame->FindFlyFrame();
// Attention: if e.g. in a column frame the size is still invalid
@@ -124,7 +124,7 @@ bool sw_ChangeOffset(SwTextFrame* pFrame, TextFrameIndex nNew)
if( pVsh->GetRingContainer().size() > 1 ||
( pFrame->GetDrawObjs() && pFrame->GetDrawObjs()->size() ) )
{
- if( !pFrame->GetOfst() )
+ if( !pFrame->GetOffset() )
return false;
nNew = TextFrameIndex(0);
}
@@ -143,7 +143,7 @@ bool sw_ChangeOffset(SwTextFrame* pFrame, TextFrameIndex nNew)
SwTextFrame& SwTextFrame::GetFrameAtOfst(TextFrameIndex const nWhere)
{
SwTextFrame* pRet = this;
- while( pRet->HasFollow() && nWhere >= pRet->GetFollow()->GetOfst() )
+ while( pRet->HasFollow() && nWhere >= pRet->GetFollow()->GetOffset() )
pRet = pRet->GetFollow();
return *pRet;
}
@@ -154,11 +154,11 @@ SwTextFrame *SwTextFrame::GetFrameAtPos( const SwPosition &rPos )
SwTextFrame *pFoll = this;
while( pFoll->GetFollow() )
{
- if (nPos > pFoll->GetFollow()->GetOfst())
+ if (nPos > pFoll->GetFollow()->GetOffset())
pFoll = pFoll->GetFollow();
else
{
- if (nPos == pFoll->GetFollow()->GetOfst()
+ if (nPos == pFoll->GetFollow()->GetOffset()
&& !SwTextCursor::IsRightMargin() )
pFoll = pFoll->GetFollow();
else
@@ -293,7 +293,7 @@ bool SwTextFrame::GetCharRect( SwRect& rOrig, const SwPosition &rPos,
if( pFrame->IsUndersized() && pCMS && !pFrame->GetNext() &&
aRectFnSet.GetBottom(rOrig) == nUpperMaxY &&
- pFrame->GetOfst() < nOffset &&
+ pFrame->GetOffset() < nOffset &&
!pFrame->IsFollow() && !bNoScroll &&
TextFrameIndex(pFrame->GetText().getLength()) != nNextOfst)
{
@@ -686,7 +686,7 @@ bool SwTextFrame::LeftMargin(SwPaM *pPam) const
aLine.CharCursorToLine(pFrame->MapModelToViewPos(*pPam->GetPoint()));
nIndx = aLine.GetStart();
- if( pFrame->GetOfst() && !pFrame->IsFollow() && !aLine.GetPrev() )
+ if( pFrame->GetOffset() && !pFrame->IsFollow() && !aLine.GetPrev() )
{
sw_ChangeOffset(pFrame, TextFrameIndex(0));
nIndx = TextFrameIndex(0);
@@ -796,9 +796,9 @@ bool SwTextFrame::UnitUp_( SwPaM *pPam, const SwTwips nOffset,
bool bSecondOfDouble = ( aInf.IsMulti() && ! aInf.IsFirstMulti() );
bool bPrevLine = ( pPrevLine && pPrevLine != aLine.GetCurr() );
- if( !pPrevLine && !bSecondOfDouble && GetOfst() && !IsFollow() )
+ if( !pPrevLine && !bSecondOfDouble && GetOffset() && !IsFollow() )
{
- nFormat = GetOfst();
+ nFormat = GetOffset();
TextFrameIndex nDiff = aLine.GetLength();
if( !nDiff )
nDiff = TextFrameIndex(MIN_OFFSET_STEP);
@@ -862,18 +862,18 @@ bool SwTextFrame::UnitUp_( SwPaM *pPam, const SwTwips nOffset,
if ( IsFollow() )
{
const SwTextFrame *pTmpPrev = FindMaster();
- TextFrameIndex nOffs = GetOfst();
+ TextFrameIndex nOffs = GetOffset();
if( pTmpPrev )
{
SwViewShell *pSh = getRootFrame()->GetCurrShell();
const bool bProtectedAllowed = pSh && pSh->GetViewOptions()->IsCursorInProtectedArea();
const SwTextFrame *pPrevPrev = pTmpPrev;
// We skip protected frames and frames without content here
- while( pPrevPrev && ( pPrevPrev->GetOfst() == nOffs ||
+ while( pPrevPrev && ( pPrevPrev->GetOffset() == nOffs ||
( !bProtectedAllowed && pPrevPrev->IsProtected() ) ) )
{
pTmpPrev = pPrevPrev;
- nOffs = pTmpPrev->GetOfst();
+ nOffs = pTmpPrev->GetOffset();
if ( pPrevPrev->IsFollow() )
pPrevPrev = pTmpPrev->FindMaster();
else
@@ -1237,11 +1237,11 @@ bool SwTextFrame::UnitDown_(SwPaM *pPam, const SwTwips nOffset,
TextFrameIndex nTmpLen(aInf.GetText().getLength());
if( aLine.GetEnd() < nTmpLen )
{
- if( nFormat <= GetOfst() )
+ if( nFormat <= GetOffset() )
{
- nFormat = std::min(GetOfst() + TextFrameIndex(MIN_OFFSET_STEP),
+ nFormat = std::min(GetOffset() + TextFrameIndex(MIN_OFFSET_STEP),
nTmpLen );
- if( nFormat <= GetOfst() )
+ if( nFormat <= GetOffset() )
break;
}
continue;
diff --git a/sw/source/core/text/frmform.cxx b/sw/source/core/text/frmform.cxx
index 482823fc8dbf..47f1345705ca 100644
--- a/sw/source/core/text/frmform.cxx
+++ b/sw/source/core/text/frmform.cxx
@@ -181,7 +181,7 @@ bool SwTextFrame::CalcFollow(TextFrameIndex const nTextOfst)
SwParaPortion *pPara = GetPara();
const bool bFollowField = pPara && pPara->IsFollowField();
- if( !pMyFollow->GetOfst() || pMyFollow->GetOfst() != nTextOfst ||
+ if( !pMyFollow->GetOffset() || pMyFollow->GetOffset() != nTextOfst ||
bFollowField || pMyFollow->IsFieldFollow() ||
( pMyFollow->IsVertical() && !pMyFollow->getFramePrintArea().Width() ) ||
( ! pMyFollow->IsVertical() && !pMyFollow->getFramePrintArea().Height() ) )
@@ -365,7 +365,7 @@ void SwTextFrame::AdjustFrame( const SwTwips nChgHght, bool bHasToFit )
vcl::RenderContext* pRenderContext = getRootFrame()->GetCurrShell()->GetOut();
if( IsUndersized() )
{
- if( GetOfst() && !IsFollow() ) // A scrolled paragraph (undersized)
+ if( GetOffset() && !IsFollow() ) // A scrolled paragraph (undersized)
return;
SetUndersized( nChgHght == 0 || bHasToFit );
}
@@ -596,7 +596,7 @@ void SwTextFrame::AdjustFollow_( SwTextFormatter &rLine,
// We steal text mass from our Follows
// It can happen that we have to join some of them
while( GetFollow() && GetFollow()->GetFollow() &&
- nNewOfst >= GetFollow()->GetFollow()->GetOfst() )
+ nNewOfst >= GetFollow()->GetFollow()->GetOffset() )
{
JoinFrame();
}
@@ -621,7 +621,7 @@ SwContentFrame *SwTextFrame::JoinFrame()
SwTextFrame *pNxt = pFoll->GetFollow();
// All footnotes of the to-be-destroyed Follow are relocated to us
- TextFrameIndex nStart = pFoll->GetOfst();
+ TextFrameIndex nStart = pFoll->GetOffset();
if ( pFoll->HasFootnote() )
{
SwFootnoteBossFrame *pFootnoteBoss = nullptr;
@@ -941,7 +941,7 @@ bool SwTextFrame::CalcPreps()
{
// We delete a line before the Master, because the Follow
// could hand over a line
- const SwCharRange aFollowRg(GetFollow()->GetOfst(), TextFrameIndex(1));
+ const SwCharRange aFollowRg(GetFollow()->GetOffset(), TextFrameIndex(1));
pPara->GetReformat() += aFollowRg;
// We should continue!
bRet = false;
@@ -990,9 +990,9 @@ bool SwTextFrame::CalcPreps()
// We rewire the footnotes and the character bound objects
void SwTextFrame::ChangeOffset( SwTextFrame* pFrame, TextFrameIndex nNew )
{
- if( pFrame->GetOfst() < nNew )
+ if( pFrame->GetOffset() < nNew )
pFrame->MoveFlyInCnt( this, TextFrameIndex(0), nNew );
- else if( pFrame->GetOfst() > nNew )
+ else if( pFrame->GetOffset() > nNew )
MoveFlyInCnt( pFrame, nNew, TextFrameIndex(COMPLETE_STRING) );
}
@@ -1092,7 +1092,7 @@ void SwTextFrame::FormatAdjust( SwTextFormatter &rLine,
// Thus, the text frame introduced a follow by a
// <SwTextFrame::SplitFrame(..)> - see below. The follow then shows
// the numbering and must stay.
- if ( GetFollow()->GetOfst() != nEnd ||
+ if ( GetFollow()->GetOffset() != nEnd ||
GetFollow()->IsFieldFollow() ||
(nStrLen == TextFrameIndex(0) && GetTextNodeForParaProps()->GetNumRule()))
{
@@ -1263,7 +1263,7 @@ bool SwTextFrame::FormatLine( SwTextFormatter &rLine, const bool bPrev )
else
nRght += ( std::max( nOldAscent, pNew->GetAscent() ) / 4);
nRght += rLine.GetLeftMargin();
- if( rRepaint.GetOfst() || rRepaint.GetRightOfst() < nRght )
+ if( rRepaint.GetOffset() || rRepaint.GetRightOfst() < nRght )
rRepaint.SetRightOfst( nRght );
// Finally we enlarge the repaint rectangle if we found an underscore
@@ -1328,7 +1328,7 @@ void SwTextFrame::Format_( SwTextFormatter &rLine, SwTextFormatInfo &rInf,
rReformat.Len() = nStrLen - rReformat.Start();
SwTwips nOldBottom;
- if( GetOfst() && !IsFollow() )
+ if( GetOffset() && !IsFollow() )
{
rLine.Bottom();
nOldBottom = rLine.Y();
@@ -1448,7 +1448,7 @@ void SwTextFrame::Format_( SwTextFormatter &rLine, SwTextFormatInfo &rInf,
if ( bMaxHyph )
rLine.InitCntHyph();
- if( IsFollow() && IsFieldFollow() && rLine.GetStart() == GetOfst() )
+ if( IsFollow() && IsFieldFollow() && rLine.GetStart() == GetOffset() )
{
SwTextFrame *pMaster = FindMaster();
OSL_ENSURE( pMaster, "SwTextFrame::Format: homeless follow" );
@@ -1465,11 +1465,11 @@ void SwTextFrame::Format_( SwTextFormatter &rLine, SwTextFormatInfo &rInf,
SwTextIter aMasterLine( pMaster, &aInf );
aMasterLine.Bottom();
pLine = aMasterLine.GetCurr();
- assert(aMasterLine.GetEnd() == GetOfst());
+ assert(aMasterLine.GetEnd() == GetOffset());
}
}
SwLinePortion* pRest = pLine ?
- rLine.MakeRestPortion(pLine, GetOfst()) : nullptr;
+ rLine.MakeRestPortion(pLine, GetOffset()) : nullptr;
if( pRest )
rInf.SetRest( pRest );
else
@@ -1858,7 +1858,7 @@ void SwTextFrame::Format( vcl::RenderContext* pRenderContext, const SwBorderAttr
SwTextLineAccess aAccess( this );
const bool bNew = !aAccess.IsAvailable();
const bool bSetOfst =
- (GetOfst() && GetOfst() > TextFrameIndex(GetText().getLength()));
+ (GetOffset() && GetOffset() > TextFrameIndex(GetText().getLength()));
if( CalcPreps() )
; // nothing
@@ -2009,9 +2009,9 @@ bool SwTextFrame::FormatQuick( bool bForceQuickFormat )
if( aLine.GetDropFormat() )
return false;
- TextFrameIndex nStart = GetOfst();
+ TextFrameIndex nStart = GetOffset();
const TextFrameIndex nEnd = GetFollow()
- ? GetFollow()->GetOfst()
+ ? GetFollow()->GetOffset()
: TextFrameIndex(aInf.GetText().getLength());
int nLoopProtection = 0;
@@ -2040,12 +2040,12 @@ bool SwTextFrame::FormatQuick( bool bForceQuickFormat )
if( !bForceQuickFormat && nNewHeight != nOldHeight && !IsUndersized() )
{
// Attention: This situation can occur due to FormatLevel==12. Don't panic!
- TextFrameIndex const nStrt = GetOfst();
+ TextFrameIndex const nStrt = GetOffset();
InvalidateRange_( SwCharRange( nStrt, nEnd - nStrt) );
return false;
}
- if (m_pFollow && nStart != static_cast<SwTextFrame*>(m_pFollow)->GetOfst())
+ if (m_pFollow && nStart != static_cast<SwTextFrame*>(m_pFollow)->GetOffset())
return false; // can be caused by e.g. Orphans
// We made it!
diff --git a/sw/source/core/text/frmpaint.cxx b/sw/source/core/text/frmpaint.cxx
index 63ee403047d9..88e188dda2ed 100644
--- a/sw/source/core/text/frmpaint.cxx
+++ b/sw/source/core/text/frmpaint.cxx
@@ -425,8 +425,8 @@ SwRect SwTextFrame::GetPaintSwRect()
if ( IsVertLR() && !IsVertLRBT()) // mba: the following line was added, but we don't need it for the existing directions; kept for IsVertLR(), but should be checked
rRepaint.Chg( GetUpper()->getFrameArea().Pos() + GetUpper()->getFramePrintArea().Pos(), GetUpper()->getFramePrintArea().SSize() );
- if( rRepaint.GetOfst() )
- rRepaint.Left( rRepaint.GetOfst() );
+ if( rRepaint.GetOffset() )
+ rRepaint.Left( rRepaint.GetOffset() );
l = rRepaint.GetRightOfst();
if( l && l > rRepaint.Right() )
@@ -625,7 +625,7 @@ void SwTextFrame::PaintSwFrame(vcl::RenderContext& rRenderContext, SwRect const&
// Switch off recycling when in the FlyContentFrame.
// A DrawRect is called for repainting the line anyways.
- if( rRepaint.GetOfst() )
+ if( rRepaint.GetOffset() )
{
const SwFlyFrame *pFly = FindFlyFrame();
if( pFly && pFly->IsFlyInContentFrame() )
diff --git a/sw/source/core/text/inftxt.cxx b/sw/source/core/text/inftxt.cxx
index b7d80e1d4f97..e4f42d4a8ea7 100644
--- a/sw/source/core/text/inftxt.cxx
+++ b/sw/source/core/text/inftxt.cxx
@@ -145,7 +145,7 @@ void SwLineInfo::CtorInitLineInfo( const SwAttrSet& rAttrSet,
void SwTextInfo::CtorInitTextInfo( SwTextFrame *pFrame )
{
m_pPara = pFrame->GetPara();
- m_nTextStart = pFrame->GetOfst();
+ m_nTextStart = pFrame->GetOffset();
if (!m_pPara)
{
SAL_WARN("sw.core", "+SwTextInfo::CTOR: missing paragraph information");
diff --git a/sw/source/core/text/inftxt.hxx b/sw/source/core/text/inftxt.hxx
index 63d030e896e9..b3bf804aff6f 100644
--- a/sw/source/core/text/inftxt.hxx
+++ b/sw/source/core/text/inftxt.hxx
@@ -736,7 +736,7 @@ inline SwPosSize SwTextSizeInfo::GetTextSize( const SwScriptInfo* pSI,
inline SwTwips SwTextPaintInfo::GetPaintOfst() const
{
- return GetParaPortion()->GetRepaint().GetOfst();
+ return GetParaPortion()->GetRepaint().GetOffset();
}
inline void SwTextPaintInfo::SetPaintOfst( const SwTwips nNew )
diff --git a/sw/source/core/text/itratr.cxx b/sw/source/core/text/itratr.cxx
index 73a907474ac2..3e3dc819c270 100644
--- a/sw/source/core/text/itratr.cxx
+++ b/sw/source/core/text/itratr.cxx
@@ -1242,7 +1242,7 @@ void SwTextNode::GetMinMaxSize( sal_uLong nIndex, sal_uLong& rMin, sal_uLong &rM
sal_uInt16 SwTextFrame::GetScalingOfSelectedText(
TextFrameIndex nStart, TextFrameIndex nEnd)
{
- assert(GetOfst() <= nStart && (!GetFollow() || nStart < GetFollow()->GetOfst()));
+ assert(GetOffset() <= nStart && (!GetFollow() || nStart < GetFollow()->GetOffset()));
SwViewShell const*const pSh = getRootFrame()->GetCurrShell();
assert(pSh);
OutputDevice *const pOut = &pSh->GetRefDev();
diff --git a/sw/source/core/text/itrcrsr.cxx b/sw/source/core/text/itrcrsr.cxx
index 09eb33c11606..6d653e7e04b3 100644
--- a/sw/source/core/text/itrcrsr.cxx
+++ b/sw/source/core/text/itrcrsr.cxx
@@ -235,7 +235,7 @@ void SwTextMargin::CtorInitTextMargin( SwTextFrame *pNewFrame, SwTextSizeInfo *p
nRight = nLeft + 1; // einen goennen wir uns immer
}
- if( m_pFrame->IsFollow() && m_pFrame->GetOfst() )
+ if( m_pFrame->IsFollow() && m_pFrame->GetOffset() )
nFirst = nLeft;
else
{
diff --git a/sw/source/core/text/itrform2.cxx b/sw/source/core/text/itrform2.cxx
index 6edf7e055184..05a25f87e5f8 100644
--- a/sw/source/core/text/itrform2.cxx
+++ b/sw/source/core/text/itrform2.cxx
@@ -1056,7 +1056,7 @@ SwLinePortion *SwTextFormatter::WhichFirstPortion(SwTextFormatInfo &rInf)
}
// We can stand in the follow, it's crucial that
- // pFrame->GetOfst() == 0!
+ // pFrame->GetOffset() == 0!
if( rInf.GetIdx() )
{
// We now too can elongate FootnotePortions and ErgoSumPortions
@@ -1072,8 +1072,8 @@ SwLinePortion *SwTextFormatter::WhichFirstPortion(SwTextFormatInfo &rInf)
// 2. Arrow portions
if( !pPor && !rInf.IsArrowDone() )
{
- if( m_pFrame->GetOfst() && !m_pFrame->IsFollow() &&
- rInf.GetIdx() == m_pFrame->GetOfst() )
+ if( m_pFrame->GetOffset() && !m_pFrame->IsFollow() &&
+ rInf.GetIdx() == m_pFrame->GetOffset() )
pPor = new SwArrowPortion( *m_pCurr );
rInf.SetArrowDone( true );
}
diff --git a/sw/source/core/text/itrtxt.cxx b/sw/source/core/text/itrtxt.cxx
index c536287e1731..b285307a8449 100644
--- a/sw/source/core/text/itrtxt.cxx
+++ b/sw/source/core/text/itrtxt.cxx
@@ -334,7 +334,7 @@ void SwTextIter::TruncLines( bool bNoteFollow )
// bug 88534: wrong positioning of flys
SwTextFrame* pFollow = GetTextFrame()->GetFollow();
if ( pFollow && ! pFollow->IsLocked() &&
- nEnd == pFollow->GetOfst() )
+ nEnd == pFollow->GetOffset() )
{
TextFrameIndex nRangeEnd = nEnd;
SwLineLayout* pLine = pDel;
diff --git a/sw/source/core/text/porlay.hxx b/sw/source/core/text/porlay.hxx
index a1427da86d15..3f7d5575b8a1 100644
--- a/sw/source/core/text/porlay.hxx
+++ b/sw/source/core/text/porlay.hxx
@@ -67,7 +67,7 @@ class SwRepaint : public SwRect
public:
SwRepaint() : SwRect(), nOfst( 0 ), nRightOfst( 0 ) {}
- SwTwips GetOfst() const { return nOfst; }
+ SwTwips GetOffset() const { return nOfst; }
void SetOfst( const SwTwips nNew ) { nOfst = nNew; }
SwTwips GetRightOfst() const { return nRightOfst; }
void SetRightOfst( const SwTwips nNew ) { nRightOfst = nNew; }
diff --git a/sw/source/core/text/txtfrm.cxx b/sw/source/core/text/txtfrm.cxx
index 06bccb92c5ae..84b5e109320f 100644
--- a/sw/source/core/text/txtfrm.cxx
+++ b/sw/source/core/text/txtfrm.cxx
@@ -1432,7 +1432,7 @@ void SwTextFrame::HideHidden()
OSL_ENSURE( !GetFollow() && IsHiddenNow(),
"HideHidden on visible frame of hidden frame has follow" );
- HideFootnotes(GetOfst(), TextFrameIndex(COMPLETE_STRING));
+ HideFootnotes(GetOffset(), TextFrameIndex(COMPLETE_STRING));
HideAndShowObjects();
// format information is obsolete
@@ -1649,7 +1649,7 @@ bool SwTextFrame::IsIdxInside(TextFrameIndex const nPos, TextFrameIndex const nL
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wstrict-overflow"
#endif
- if (nLen != TextFrameIndex(COMPLETE_STRING) && GetOfst() > nPos + nLen) // the range preceded us
+ if (nLen != TextFrameIndex(COMPLETE_STRING) && GetOffset() > nPos + nLen) // the range preceded us
#if defined __GNUC__ && !defined __clang__
#pragma GCC diagnostic pop
#endif
@@ -1658,7 +1658,7 @@ bool SwTextFrame::IsIdxInside(TextFrameIndex const nPos, TextFrameIndex const nL
if( !GetFollow() ) // the range doesn't precede us,
return true; // nobody follows us.
- TextFrameIndex const nMax = GetFollow()->GetOfst();
+ TextFrameIndex const nMax = GetFollow()->GetOffset();
// either the range overlap or our text has been deleted
// sw_redlinehide: GetText() should be okay here because it has already
@@ -1859,10 +1859,10 @@ static void lcl_ModifyOfst(SwTextFrame & rFrame,
TextFrameIndex (* op)(TextFrameIndex const&, TextFrameIndex const&))
{
assert(nLen != TextFrameIndex(COMPLETE_STRING));
- if (rFrame.IsFollow() && nPos < rFrame.GetOfst())
+ if (rFrame.IsFollow() && nPos < rFrame.GetOffset())
{
- rFrame.ManipOfst( std::max(nPos, op(rFrame.GetOfst(), nLen)) );
- assert(sal_Int32(rFrame.GetOfst()) <= rFrame.GetText().getLength());
+ rFrame.ManipOfst( std::max(nPos, op(rFrame.GetOffset(), nLen)) );
+ assert(sal_Int32(rFrame.GetOffset()) <= rFrame.GetText().getLength());
}
}
@@ -2685,14 +2685,14 @@ static bool lcl_ErgoVadis(SwTextFrame* pFrame, TextFrameIndex & rPos, const Prep
{
if( rFootnoteInfo.m_aErgoSum.isEmpty() )
return false;
- rPos = pFrame->GetOfst();
+ rPos = pFrame->GetOffset();
}
else
{
if( rFootnoteInfo.m_aQuoVadis.isEmpty() )
return false;
if( pFrame->HasFollow() )
- rPos = pFrame->GetFollow()->GetOfst();
+ rPos = pFrame->GetFollow()->GetOffset();
else
rPos = TextFrameIndex(pFrame->GetText().getLength());
if( rPos )
@@ -2798,7 +2798,7 @@ bool SwTextFrame::Prepare( const PrepareHint ePrep, const void* pVoid,
IsUndersized() )
{
InvalidateRange(SwCharRange(TextFrameIndex(0), TextFrameIndex(1)), 1);
- if( GetOfst() && !IsFollow() )
+ if( GetOffset() && !IsFollow() )
SetOfst_(TextFrameIndex(0));
}
break;
@@ -2858,12 +2858,12 @@ bool SwTextFrame::Prepare( const PrepareHint ePrep, const void* pVoid,
bool bOld = IsVertical();
SetInvalidVert( true );
if( bOld != IsVertical() )
- InvalidateRange(SwCharRange(GetOfst(), TextFrameIndex(COMPLETE_STRING)));
+ InvalidateRange(SwCharRange(GetOffset(), TextFrameIndex(COMPLETE_STRING)));
}
if( HasFollow() )
{
- TextFrameIndex nNxtOfst = GetFollow()->GetOfst();
+ TextFrameIndex nNxtOfst = GetFollow()->GetOffset();
if( nNxtOfst )
--nNxtOfst;
InvalidateRange(SwCharRange( nNxtOfst, TextFrameIndex(1)), 1);
@@ -2880,11 +2880,11 @@ bool SwTextFrame::Prepare( const PrepareHint ePrep, const void* pVoid,
SwTextNode const* pNode(nullptr);
sw::MergedAttrIter iter(*this);
TextFrameIndex const nEnd = GetFollow()
- ? GetFollow()->GetOfst() : TextFrameIndex(COMPLETE_STRING);
+ ? GetFollow()->GetOffset() : TextFrameIndex(COMPLETE_STRING);
for (SwTextAttr const* pHt = iter.NextAttr(&pNode); pHt; pHt = iter.NextAttr(&pNode))
{
TextFrameIndex const nStart(MapModelToView(pNode, pHt->GetStart()));
- if (nStart >= GetOfst())
+ if (nStart >= GetOffset())
{
if (nStart >= nEnd)
break;
@@ -2903,7 +2903,7 @@ bool SwTextFrame::Prepare( const PrepareHint ePrep, const void* pVoid,
if( IsUndersized() )
{
InvalidateSize_();
- InvalidateRange(SwCharRange(GetOfst(), TextFrameIndex(1)), 1);
+ InvalidateRange(SwCharRange(GetOffset(), TextFrameIndex(1)), 1);
}
break;
}
@@ -3023,8 +3023,8 @@ bool SwTextFrame::Prepare( const PrepareHint ePrep, const void* pVoid,
// Which had flowed to the next page to be together with the footnote (this is
// especially true for areas with columns)
OSL_ENSURE( GetFollow(), "PrepareHint::FootnoteInvalidationGone may only be called by Follow" );
- TextFrameIndex nPos = GetFollow()->GetOfst();
- if( IsFollow() && GetOfst() == nPos ) // If we don't have a mass of text, we call our
+ TextFrameIndex nPos = GetFollow()->GetOffset();
+ if( IsFollow() && GetOffset() == nPos ) // If we don't have a mass of text, we call our
FindMaster()->Prepare( PrepareHint::FootnoteInvalidationGone ); // Master's Prepare
if( nPos )
--nPos; // The char preceding our Follow
@@ -3058,10 +3058,10 @@ bool SwTextFrame::Prepare( const PrepareHint ePrep, const void* pVoid,
if( PrepareHint::FlyFrameArrive == ePrep || PrepareHint::FlyFrameLeave == ePrep )
{
TextFrameIndex const nLen = (GetFollow()
- ? GetFollow()->GetOfst()
+ ? GetFollow()->GetOffset()
: TextFrameIndex(COMPLETE_STRING))
- - GetOfst();
- InvalidateRange( SwCharRange( GetOfst(), nLen ) );
+ - GetOffset();
+ InvalidateRange( SwCharRange( GetOffset(), nLen ) );
}
}
else
@@ -3070,7 +3070,7 @@ bool SwTextFrame::Prepare( const PrepareHint ePrep, const void* pVoid,
SetCompletePaint();
Init();
pPara = nullptr;
- if( GetOfst() && !IsFollow() )
+ if( GetOffset() && !IsFollow() )
SetOfst_( TextFrameIndex(0) );
if ( bNotify )
InvalidateSize();
@@ -3333,7 +3333,7 @@ sal_uInt16 SwTextFrame::GetParHeight() const
// Is this paragraph scrolled? Our height until now is at least
// one line height too low then
- if( GetOfst() && !IsFollow() )
+ if( GetOffset() && !IsFollow() )
nHeight *= 2;
while ( pLineLayout && pLineLayout->GetNext() )
@@ -3745,7 +3745,7 @@ sal_uInt16 SwTextFrame::GetLineCount(TextFrameIndex const nPos)
aLine.CharToLine( nPos );
nRet = nRet + aLine.GetLineNr();
pFrame = pFrame->GetFollow();
- } while ( pFrame && pFrame->GetOfst() <= nPos );
+ } while ( pFrame && pFrame->GetOffset() <= nPos );
return nRet;
}
@@ -3865,7 +3865,7 @@ void SwTextFrame::VisitPortions( SwPortionHandler& rPH ) const
if (pPara)
{
if ( IsFollow() )
- rPH.Skip( GetOfst() );
+ rPH.Skip( GetOffset() );
const SwLineLayout* pLine = pPara;
while ( pLine )
diff --git a/sw/source/core/text/widorp.cxx b/sw/source/core/text/widorp.cxx
index f45b3d59f64e..2a6692cef371 100644
--- a/sw/source/core/text/widorp.cxx
+++ b/sw/source/core/text/widorp.cxx
@@ -367,7 +367,7 @@ bool WidowsAndOrphans::FindWidows( SwTextFrame *pFrame, SwTextMargin &rLine )
// If the first line of the Follow does not fit, the master
// probably is full of Dummies. In this case a PrepareHint::Widows would be fatal.
- if( pMaster->GetOfst() == pFrame->GetOfst() )
+ if( pMaster->GetOffset() == pFrame->GetOffset() )
return false;
// Remaining height of the master
diff --git a/sw/source/core/txtnode/fntcache.cxx b/sw/source/core/txtnode/fntcache.cxx
index 09b62124f7fa..0ed8984d4ec6 100644
--- a/sw/source/core/txtnode/fntcache.cxx
+++ b/sw/source/core/txtnode/fntcache.cxx
@@ -2191,8 +2191,8 @@ TextFrameIndex SwFntObj::GetCursorOfst(SwDrawTextInfo &rInf)
nAvgWidthPerChar = i * nGridWidth;
// stupid CLANG
- nCnt = TextFrameIndex(rInf.GetOfst() / nAvgWidthPerChar);
- if (2 * (rInf.GetOfst() - sal_Int32(nCnt) * nAvgWidthPerChar) > nAvgWidthPerChar)
+ nCnt = TextFrameIndex(rInf.GetOffset() / nAvgWidthPerChar);
+ if (2 * (rInf.GetOffset() - sal_Int32(nCnt) * nAvgWidthPerChar) > nAvgWidthPerChar)
++nCnt;
return nCnt;
@@ -2211,7 +2211,7 @@ TextFrameIndex SwFntObj::GetCursorOfst(SwDrawTextInfo &rInf)
for (TextFrameIndex j(0); j < rInf.GetLen(); j++)
{
long nScr = pKernArray[sal_Int32(j)] + (nSpaceAdd + nGridWidthAdd) * (sal_Int32(j) + 1);
- if( nScr >= rInf.GetOfst())
+ if( nScr >= rInf.GetOffset())
{
nCnt = j;
break;
@@ -2230,7 +2230,7 @@ TextFrameIndex SwFntObj::GetCursorOfst(SwDrawTextInfo &rInf)
// skip character cells for all script types
LanguageType aLang = rInf.GetFont()->GetLanguage();
- while ( ( nRight < long( rInf.GetOfst() ) ) && ( nIdx < nEnd ) )
+ while ( ( nRight < long( rInf.GetOffset() ) ) && ( nIdx < nEnd ) )
{
if (nSpaceAdd && CH_BLANK == rInf.GetText()[ sal_Int32(nIdx)])
nSpaceSum += nSpaceAdd;
@@ -2255,8 +2255,8 @@ TextFrameIndex SwFntObj::GetCursorOfst(SwDrawTextInfo &rInf)
// or if we do not want to go to the next character
if ( nIdx > rInf.GetIdx() &&
( rInf.IsPosMatchesBounds() ||
- ( ( nRight > long( rInf.GetOfst() ) ) &&
- ( nRight - rInf.GetOfst() > rInf.GetOfst() - nLeft ) ) ) )
+ ( ( nRight > long( rInf.GetOffset() ) ) &&
+ ( nRight - rInf.GetOffset() > rInf.GetOffset() - nLeft ) ) ) )
nCnt = nLastIdx - rInf.GetIdx(); // first half
else
nCnt = nIdx - rInf.GetIdx(); // second half
diff --git a/sw/source/core/txtnode/fntcap.cxx b/sw/source/core/txtnode/fntcap.cxx
index e253e3bd5681..da9382f78f88 100644
--- a/sw/source/core/txtnode/fntcap.cxx
+++ b/sw/source/core/txtnode/fntcap.cxx
@@ -395,7 +395,7 @@ TextFrameIndex SwSubFont::GetCapitalCursorOfst( SwDrawTextInfo& rInf )
{
const long nOldKern = rInf.GetKern();
rInf.SetKern( CheckKerning() );
- SwDoCapitalCursorOfst aDo( rInf, rInf.GetOfst() );
+ SwDoCapitalCursorOfst aDo( rInf, rInf.GetOffset() );
rInf.SetPos( Point() );
rInf.SetDrawSpace( false );
DoOnCapitals( aDo );
diff --git a/sw/source/core/txtnode/ndtxt.cxx b/sw/source/core/txtnode/ndtxt.cxx
index be604ee78542..97b975f90e30 100644
--- a/sw/source/core/txtnode/ndtxt.cxx
+++ b/sw/source/core/txtnode/ndtxt.cxx
@@ -543,7 +543,7 @@ SwTextNode *SwTextNode::SplitContentNode(const SwPosition & rPos,
for (SwTextFrame * pFrame : frames)
{
pFrame->RegisterToNode( *pNode );
- if (!pFrame->IsFollow() && pFrame->GetOfst())
+ if (!pFrame->IsFollow() && pFrame->GetOffset())
{
pFrame->SetOfst( TextFrameIndex(0) );
}
diff --git a/sw/source/core/txtnode/txtedt.cxx b/sw/source/core/txtnode/txtedt.cxx
index e7f6a326dae2..dcddfb5f0f48 100644
--- a/sw/source/core/txtnode/txtedt.cxx
+++ b/sw/source/core/txtnode/txtedt.cxx
@@ -224,11 +224,11 @@ static SwRect lcl_CalculateRepaintRect(
const SwTextFrame* pStartFrame = &rTextFrame;
while( pStartFrame->HasFollow() &&
- iChgStart >= pStartFrame->GetFollow()->GetOfst())
+ iChgStart >= pStartFrame->GetFollow()->GetOffset())
pStartFrame = pStartFrame->GetFollow();
const SwTextFrame* pEndFrame = pStartFrame;
while( pEndFrame->HasFollow() &&
- iChgEnd >= pEndFrame->GetFollow()->GetOfst())
+ iChgEnd >= pEndFrame->GetFollow()->GetOffset())
pEndFrame = pEndFrame->GetFollow();
bool bSameFrame = true;
@@ -1655,8 +1655,8 @@ bool SwTextNode::Hyphenate( SwInterHyphInfo &rHyphInf )
pFrame = pFrame->GetFollow();
if( pFrame )
{
- aHyphInfo.m_nEnd = aHyphInfo.m_nEnd - (pFrame->GetOfst() - aHyphInfo.m_nStart);
- aHyphInfo.m_nStart = pFrame->GetOfst();
+ aHyphInfo.m_nEnd = aHyphInfo.m_nEnd - (pFrame->GetOffset() - aHyphInfo.m_nStart);
+ aHyphInfo.m_nStart = pFrame->GetOffset();
}
}
return false;
diff --git a/sw/source/core/text/txtftn.cxx b/sw/source/core/text/txtftn.cxx
index 4df50b14e5cc..97557d7ad98e 100644
--- a/sw/source/core/text/txtftn.cxx
+++ b/sw/source/core/text/txtftn.cxx
@@ -71,7 +71,7 @@ bool SwTextFrame::IsFootnoteNumFrame_() const
SwTextFrame *SwTextFrame::FindFootnoteRef( const SwTextFootnote *pFootnote )
{
SwTextFrame *pFrame = this;
- const bool bFwd = MapModelToView(&pFootnote->GetTextNode(), pFootnote->GetStart()) >= GetOfst();
+ const bool bFwd = MapModelToView(&pFootnote->GetTextNode(), pFootnote->GetStart()) >= GetOffset();
while( pFrame )
{
if( SwFootnoteBossFrame::FindFootnote( pFrame, pFootnote ) )
@@ -98,10 +98,10 @@ void SwTextFrame::CalcFootnoteFlag()
#ifdef DBG_UTIL
const TextFrameIndex nEnd = nStop != TextFrameIndex(COMPLETE_STRING)
? nStop
- : GetFollow() ? GetFollow()->GetOfst() : TextFrameIndex(COMPLETE_STRING);
+ : GetFollow() ? GetFollow()->GetOffset() : TextFrameIndex(COMPLETE_STRING);
#else
const TextFrameIndex nEnd = GetFollow()
- ? GetFollow()->GetOfst()
+ ? GetFollow()->GetOffset()
: TextFrameIndex(COMPLETE_STRING);
#endif
@@ -114,7 +114,7 @@ void SwTextFrame::CalcFootnoteFlag()
TextFrameIndex const nIdx(MapModelToView(pNode, pHt->GetStart()));
if ( nEnd < nIdx )
break;
- if( GetOfst() <= nIdx )
+ if( GetOffset() <= nIdx )
{
mbFootnote = true;
break;
@@ -458,10 +458,10 @@ void SwTextFrame::RemoveFootnote(TextFrameIndex const nStart, TextFrameIndex con
// 1) There's neither Follow nor PrevFollow:
// -> RemoveFootnote() (maybe even a OSL_ENSURE(value))
//
// 2) nStart > GetOfst, I have a Follow
// -> Footnote moves into Follow
//
// 3) nStart < GetOfst, I am a Follow
// -> Footnote moves into the PrevFollow
//
// Both need to be on one Page/in one Column
@@ -483,7 +483,7 @@ void SwTextFrame::RemoveFootnote(TextFrameIndex const nStart, TextFrameIndex con
{
SwContentFrame *pDest = GetFollow();
while (pDest->GetFollow() && static_cast<SwTextFrame*>(pDest->
- GetFollow())->GetOfst() <= nIdx)
+ GetFollow())->GetOffset() <= nIdx)
pDest = pDest->GetFollow();
OSL_ENSURE( !SwFootnoteBossFrame::FindFootnote(
pDest,pFootnote),"SwTextFrame::RemoveFootnote: footnote exists");
@@ -546,9 +546,9 @@ void SwTextFrame::RemoveFootnote(TextFrameIndex const nStart, TextFrameIndex con
// it'll be set soon. CalcFntFlag depends on a correctly set Follow Offset.
// Therefore we temporarily calculate the Follow Offset here
TextFrameIndex nOldOfst(COMPLETE_STRING);
- if( HasFollow() && nStart > GetOfst() )
+ if( HasFollow() && nStart > GetOffset() )
{
- nOldOfst = GetFollow()->GetOfst();
+ nOldOfst = GetFollow()->GetOffset();
GetFollow()->ManipOfst(nStart + (bRollBack ? nLen : TextFrameIndex(0)));
}
pSource->CalcFootnoteFlag();
@@ -1000,7 +1000,7 @@ SwErgoSumPortion *SwTextFormatter::NewErgoSumPortion( SwTextFormatInfo const &rI
{
// We cannot assume we're a Follow
if( !m_pFrame->IsInFootnote() || m_pFrame->GetPrev() ||
- rInf.IsErgoDone() || rInf.GetIdx() != m_pFrame->GetOfst() ||
+ rInf.IsErgoDone() || rInf.GetIdx() != m_pFrame->GetOffset() ||
m_pFrame->ImplFindFootnoteFrame()->GetAttr()->GetFootnote().IsEndNote() )
return nullptr;
@@ -458,10 +458,10 @@ void SwTextFrame::RemoveFootnote(TextFrameIndex const nStart, TextFrameIndex con
// -> RemoveFootnote() (maybe even a OSL_ENSURE(value))
//
- // 2) nStart > GetOfst, I have a Follow
+ // 2) nStart > GetOffset, I have a Follow
// -> Footnote moves into Follow
//
@@ -458,10 +458,10 @@ void SwTextFrame::RemoveFootnote(TextFrameIndex const nStart, TextFrameIndex con
// -> Footnote moves into Follow
//
- // 3) nStart < GetOfst, I am a Follow
+ // 3) nStart < GetOffset, I am a Follow
// -> Footnote moves into the PrevFollow
//